==> jc-1.4.0.tar.gz: ppg/cmds/TransferCmd.h <==
// public class ppg.cmds.TransferCmd

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 219699643e6b25cc ppg_cmds_TransferCmd

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_cmds_TransferCmd_H_
#define _JC_ppg_cmds_TransferCmd_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Vector$object;
struct _jc_ppg_atoms_Nonterminal$object;
struct _jc_ppg_util_CodeWriter$object;

// Typedefs
typedef struct _jc_ppg_cmds_TransferCmd$sub_refs	_jc_ppg_cmds_TransferCmd$sub_refs;
typedef struct _jc_ppg_cmds_TransferCmd$sub_nonrefs	_jc_ppg_cmds_TransferCmd$sub_nonrefs;
typedef struct _jc_ppg_cmds_TransferCmd$refs	_jc_ppg_cmds_TransferCmd$refs;
typedef struct _jc_ppg_cmds_TransferCmd$nonrefs	_jc_ppg_cmds_TransferCmd$nonrefs;
typedef struct _jc_ppg_cmds_TransferCmd$object	_jc_ppg_cmds_TransferCmd$object;

typedef const struct _jc_ppg_cmds_TransferCmd$vmethods	_jc_ppg_cmds_TransferCmd$vmethods;
typedef const struct _jc_ppg_cmds_TransferCmd$vtable	_jc_ppg_cmds_TransferCmd$vtable;
typedef const struct _jc_ppg_cmds_TransferCmd$vtype	_jc_ppg_cmds_TransferCmd$vtype;

// Constructors
extern void _jc_ppg_cmds_TransferCmd$method$_init$e2f4d4d6d819f45a(_jc_env *, struct _jc_ppg_cmds_TransferCmd$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Vector$object *);

// Virtual methods
extern struct _jc_ppg_atoms_Nonterminal$object *_jc_ppg_cmds_TransferCmd$method$getSource$6a7ab07414158476(_jc_env *, struct _jc_ppg_cmds_TransferCmd$object *);
extern struct _jc_java_util_Vector$object *_jc_ppg_cmds_TransferCmd$method$getTransferList$92d45aca04670d65(_jc_env *, struct _jc_ppg_cmds_TransferCmd$object *);
extern void _jc_ppg_cmds_TransferCmd$method$unparse$3d4a69bf2fda9799(_jc_env *, struct _jc_ppg_cmds_TransferCmd$object *, struct _jc_ppg_util_CodeWriter$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_cmds_TransferCmd$method_info$getSource$6a7ab07414158476;
extern _jc_method _jc_ppg_cmds_TransferCmd$method_info$getTransferList$92d45aca04670d65;
extern _jc_method _jc_ppg_cmds_TransferCmd$method_info$unparse$3d4a69bf2fda9799;

// Virtual methods structure
struct _jc_ppg_cmds_TransferCmd$vmethods {
	struct _jc_ppg_atoms_Nonterminal$object	*(*getSource$6a7ab07414158476)(_jc_env *, struct _jc_ppg_cmds_TransferCmd$object *);
	struct _jc_java_util_Vector$object	*(*getTransferList$92d45aca04670d65)(_jc_env *, struct _jc_ppg_cmds_TransferCmd$object *);
	void	(*unparse$3d4a69bf2fda9799)(_jc_env *, struct _jc_ppg_cmds_TransferCmd$object *, struct _jc_ppg_util_CodeWriter$object *);
};

// Vtable
struct _jc_ppg_cmds_TransferCmd$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_cmds_TransferCmd$vmethods	ppg_cmds_TransferCmd;
};

// Vtype
struct _jc_ppg_cmds_TransferCmd$vtype {
	_jc_type			type;
	_jc_ppg_cmds_TransferCmd$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_cmds_TransferCmd$sub_refs {
	struct _jc_ppg_atoms_Nonterminal$object	*nonterminal;
	struct _jc_java_util_Vector$object	*transferList;
};

// Reference instance fields (object)
struct _jc_ppg_cmds_TransferCmd$refs {
    _jc_ppg_cmds_TransferCmd$sub_refs	ppg_cmds_TransferCmd;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_cmds_TransferCmd$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_cmds_TransferCmd$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_cmds_TransferCmd$sub_nonrefs	ppg_cmds_TransferCmd;
};

// Object instance structure
struct _jc_ppg_cmds_TransferCmd$object {
	_jc_ppg_cmds_TransferCmd$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_cmds_TransferCmd$vtype	*vtype;
	_jc_ppg_cmds_TransferCmd$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_cmds_TransferCmd$vtype _jc_ppg_cmds_TransferCmd$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_cmds_TransferCmd, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_cmds_TransferCmd$class_object;

#endif	/* _JC_ppg_cmds_TransferCmd_H_ */

==> jc-1.4.6.tar.gz: ppg/cmds/TransferCmd.h <==
// public class ppg.cmds.TransferCmd

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 219699643e6b25cc ppg_cmds_TransferCmd

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_cmds_TransferCmd_H_
#define _JC_ppg_cmds_TransferCmd_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Vector$object;
struct _jc_ppg_atoms_Nonterminal$object;
struct _jc_ppg_util_CodeWriter$object;

// Typedefs
typedef struct _jc_ppg_cmds_TransferCmd$sub_refs	_jc_ppg_cmds_TransferCmd$sub_refs;
typedef struct _jc_ppg_cmds_TransferCmd$sub_nonrefs	_jc_ppg_cmds_TransferCmd$sub_nonrefs;
typedef struct _jc_ppg_cmds_TransferCmd$refs	_jc_ppg_cmds_TransferCmd$refs;
typedef struct _jc_ppg_cmds_TransferCmd$nonrefs	_jc_ppg_cmds_TransferCmd$nonrefs;
typedef struct _jc_ppg_cmds_TransferCmd$object	_jc_ppg_cmds_TransferCmd$object;

typedef const struct _jc_ppg_cmds_TransferCmd$vmethods	_jc_ppg_cmds_TransferCmd$vmethods;
typedef const struct _jc_ppg_cmds_TransferCmd$vtable	_jc_ppg_cmds_TransferCmd$vtable;
typedef const struct _jc_ppg_cmds_TransferCmd$vtype	_jc_ppg_cmds_TransferCmd$vtype;

// Constructors
extern void _jc_ppg_cmds_TransferCmd$method$_init$e2f4d4d6d819f45a(_jc_env *, struct _jc_ppg_cmds_TransferCmd$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Vector$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_ppg_atoms_Nonterminal$object *_jc_ppg_cmds_TransferCmd$method$getSource$6a7ab07414158476(_jc_env *, struct _jc_ppg_cmds_TransferCmd$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_Vector$object *_jc_ppg_cmds_TransferCmd$method$getTransferList$92d45aca04670d65(_jc_env *, struct _jc_ppg_cmds_TransferCmd$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_cmds_TransferCmd$method$unparse$3d4a69bf2fda9799(_jc_env *, struct _jc_ppg_cmds_TransferCmd$object *, struct _jc_ppg_util_CodeWriter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_cmds_TransferCmd$method_info$getSource$6a7ab07414158476;
extern _jc_method _jc_ppg_cmds_TransferCmd$method_info$getTransferList$92d45aca04670d65;
extern _jc_method _jc_ppg_cmds_TransferCmd$method_info$unparse$3d4a69bf2fda9799;

// Virtual methods structure
struct _jc_ppg_cmds_TransferCmd$vmethods {
	struct _jc_ppg_atoms_Nonterminal$object	*(*getSource$6a7ab07414158476)(_jc_env *, struct _jc_ppg_cmds_TransferCmd$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_Vector$object	*(*getTransferList$92d45aca04670d65)(_jc_env *, struct _jc_ppg_cmds_TransferCmd$object *) _JC_JCNI_ATTR;
	void	(*unparse$3d4a69bf2fda9799)(_jc_env *, struct _jc_ppg_cmds_TransferCmd$object *, struct _jc_ppg_util_CodeWriter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_cmds_TransferCmd$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_cmds_TransferCmd$vmethods	ppg_cmds_TransferCmd;
};

// Vtype
struct _jc_ppg_cmds_TransferCmd$vtype {
	_jc_type			type;
	_jc_ppg_cmds_TransferCmd$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_cmds_TransferCmd$sub_refs {
	struct _jc_ppg_atoms_Nonterminal$object	*nonterminal;
	struct _jc_java_util_Vector$object	*transferList;
};

// Reference instance fields (object)
struct _jc_ppg_cmds_TransferCmd$refs {
    _jc_ppg_cmds_TransferCmd$sub_refs	ppg_cmds_TransferCmd;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_cmds_TransferCmd$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_cmds_TransferCmd$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_cmds_TransferCmd$sub_nonrefs	ppg_cmds_TransferCmd;
};

// Object instance structure
struct _jc_ppg_cmds_TransferCmd$object {
	_jc_ppg_cmds_TransferCmd$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_cmds_TransferCmd$vtype	*vtype;
	_jc_ppg_cmds_TransferCmd$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_cmds_TransferCmd$vtype _jc_ppg_cmds_TransferCmd$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_cmds_TransferCmd, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_cmds_TransferCmd$class_object;

#endif	/* _JC_ppg_cmds_TransferCmd_H_ */
